# pimux

> PIMUX is here, made with :heart:

## What is pimux?
> pimux is a python module created by me to access the termux-api(hardware
> and software api). To ease the access of these beautiful api's which 
> can be really useful for IOT projects deploying using your own android phone.

## Why to use pimux?
> For every pythonist and ethusiast pymux can really ease harware and sofware
> access through termux-api.

## Special thanks 
 I would like thank every developer before me who made this beautiful
 language(python),termu-api, termux, os(linux), and all others, on whose
 contributions I have been able to make this.

> This project is originally located at [pimux](https://github.com/azwyane/pymux)


[![Build Status](http://img.shields.io/travis/badges/badgerbadgerbadger.svg?style=flat-square)](https://github.com/azwyane/pymux.git)

## Table of Contents (Optional)
- [Requirements](#Requirements)
- [Installation](#Installation)
- [Features](#Features)
- [Contributing](#Contributing)

## Requirements

- Temux app
- Termux-api (both app and package)
- Python

## Installation

🚀&nbsp; To install in your local machine follow the steps below:

### Method-1

- Clone this repo to your local machine(termux) using `https://github.com/azwyane/pymux.git`

Goto to your terminal and type:

```sh
git clone https://github.com/azwyane/pymux.git
```

## Run the project

> Now to run the pymux type in your terminal:
```
$from pimux import function   #for misc api
$from pimux import Sensors    #for sensor data
```

## Features

❤️&nbsp;
> It is a side project of making use of android sensors and IOT projects. 
> It has the feature of termux-api which can be easily used with
> python projects.


---

## Contributing

🤝&nbsp;

> To get started...

### Step 1

- Option 1
    - 🍴 Fork this repo!

- Option 2
    - 👯 Clone this repo to your local machine using `https://github.com/azwyane/pymux.git`

### Step 2

- HACK AWAY!

### Step 3

- 🔃 Create a new pull request using <a href="https://github.com/azwyane/pymux/compare" target="_blank">`https://github.com/azwyane/pymux/compare`</a>.


---

###  Found a bug? Missing a specific feature?

Feel free to **file a new issue** with a respective title and description on the the [azwyane/pymux](https://github.com/azwyane/pymux/issues) repository. If you already found a solution to your problem, **I would love to review your pull request**!

